# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: typing_and_online.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from . import peers_pb2 as peers__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='typing_and_online.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=_b('\342?\026\n\024im.dlg.grpc.services'),
  serialized_pb=_b('\n\x17typing_and_online.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x13miscellaneous.proto\x1a\x0bpeers.proto\x1a\x15scalapb/scalapb.proto\"\x93\x01\n\rRequestTyping\x12,\n\x04peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x36\n\x0btyping_type\x18\x03 \x01(\x0e\x32\x12.dialog.TypingTypeB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x97\x01\n\x11RequestStopTyping\x12,\n\x04peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible\x12\x36\n\x0btyping_type\x18\x02 \x01(\x0e\x32\x12.dialog.TypingTypeB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xf0\x01\n\x10RequestSetOnline\x12 \n\tis_online\x18\x01 \x01(\x08\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x07timeout\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x36\n\x0b\x64\x65vice_type\x18\x03 \x01(\x0e\x32\x12.dialog.DeviceTypeB\r\x8a\xea\x30\t\n\x07visible\x12\x44\n\x0f\x64\x65vice_category\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\":\n\x18UpdatePauseNotifications\x12\x1e\n\x07timeout\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"\x1c\n\x1aUpdateRestoreNotifications\"X\n\x19RequestPauseNotifications\x12\x1d\n\x07timeout\x18\x01 \x01(\x05\x42\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\";\n\x1bRequestRestoreNotifications:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x8d\x01\n\x0cUpdateTyping\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03uid\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x36\n\x0btyping_type\x18\x03 \x01(\x0e\x32\x12.dialog.TypingTypeB\r\x8a\xea\x30\t\n\x07visible\"\x90\x01\n\x10UpdateTypingStop\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03uid\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x35\n\x0btyping_type\x18\x03 \x01(\x0e\x32\x12.dialog.TypingTypeB\x0c\x8a\xea\x30\x08\n\x06hidden\"\x8e\x01\n\x10UpdateUserOnline\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\'\n\x0b\x64\x65vice_type\x18\x02 \x01(\x0e\x32\x12.dialog.DeviceType\x12\x35\n\x0f\x64\x65vice_category\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x8f\x01\n\x11UpdateUserOffline\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\'\n\x0b\x64\x65vice_type\x18\x02 \x01(\x0e\x32\x12.dialog.DeviceType\x12\x35\n\x0f\x64\x65vice_category\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xad\x01\n\x12UpdateUserLastSeen\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1b\n\x04\x64\x61te\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\'\n\x0b\x64\x65vice_type\x18\x03 \x01(\x0e\x32\x12.dialog.DeviceType\x12\x35\n\x0f\x64\x65vice_category\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"R\n\x11UpdateGroupOnline\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05\x63ount\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible*9\n\nTypingType\x12\x16\n\x12TYPINGTYPE_UNKNOWN\x10\x00\x12\x13\n\x0fTYPINGTYPE_TEXT\x10\x01*\xd4\x01\n\nDeviceType\x12\x16\n\x12\x44\x45VICETYPE_UNKNOWN\x10\x00\x12\x16\n\x12\x44\x45VICETYPE_GENERIC\x10\x01\x12\x11\n\rDEVICETYPE_PC\x10\x02\x12\x15\n\x11\x44\x45VICETYPE_MOBILE\x10\x03\x12\x15\n\x11\x44\x45VICETYPE_TABLET\x10\x04\x12\x14\n\x10\x44\x45VICETYPE_WATCH\x10\x05\x12\x15\n\x11\x44\x45VICETYPE_MIRROR\x10\x06\x12\x12\n\x0e\x44\x45VICETYPE_CAR\x10\x07\x12\x14\n\x10\x44\x45VICETYPE_TABLE\x10\x08\x32\xe5\x04\n\x0fTypingAndOnline\x12\x61\n\x06Typing\x12\x15.dialog.RequestTyping\x1a\x14.dialog.ResponseVoid\"*\x82\xd3\xe4\x93\x02$\"\x1f/v1/grpc/TypingAndOnline/Typing:\x01*\x12m\n\nStopTyping\x12\x19.dialog.RequestStopTyping\x1a\x14.dialog.ResponseVoid\".\x82\xd3\xe4\x93\x02(\"#/v1/grpc/TypingAndOnline/StopTyping:\x01*\x12j\n\tSetOnline\x12\x18.dialog.RequestSetOnline\x1a\x14.dialog.ResponseVoid\"-\x82\xd3\xe4\x93\x02\'\"\"/v1/grpc/TypingAndOnline/SetOnline:\x01*\x12\x85\x01\n\x12PauseNotifications\x12!.dialog.RequestPauseNotifications\x1a\x14.dialog.ResponseVoid\"6\x82\xd3\xe4\x93\x02\x30\"+/v1/grpc/TypingAndOnline/PauseNotifications:\x01*\x12\x8b\x01\n\x14RestoreNotifications\x12#.dialog.RequestRestoreNotifications\x1a\x14.dialog.ResponseVoid\"8\x82\xd3\xe4\x93\x02\x32\"-/v1/grpc/TypingAndOnline/RestoreNotifications:\x01*B\x19\xe2?\x16\n\x14im.dlg.grpc.servicesb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,miscellaneous__pb2.DESCRIPTOR,peers__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])

_TYPINGTYPE = _descriptor.EnumDescriptor(
  name='TypingType',
  full_name='dialog.TypingType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TYPINGTYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TYPINGTYPE_TEXT', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1803,
  serialized_end=1860,
)
_sym_db.RegisterEnumDescriptor(_TYPINGTYPE)

TypingType = enum_type_wrapper.EnumTypeWrapper(_TYPINGTYPE)
_DEVICETYPE = _descriptor.EnumDescriptor(
  name='DeviceType',
  full_name='dialog.DeviceType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEVICETYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICETYPE_GENERIC', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICETYPE_PC', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICETYPE_MOBILE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICETYPE_TABLET', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICETYPE_WATCH', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICETYPE_MIRROR', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICETYPE_CAR', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICETYPE_TABLE', index=8, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1863,
  serialized_end=2075,
)
_sym_db.RegisterEnumDescriptor(_DEVICETYPE)

DeviceType = enum_type_wrapper.EnumTypeWrapper(_DEVICETYPE)
TYPINGTYPE_UNKNOWN = 0
TYPINGTYPE_TEXT = 1
DEVICETYPE_UNKNOWN = 0
DEVICETYPE_GENERIC = 1
DEVICETYPE_PC = 2
DEVICETYPE_MOBILE = 3
DEVICETYPE_TABLET = 4
DEVICETYPE_WATCH = 5
DEVICETYPE_MIRROR = 6
DEVICETYPE_CAR = 7
DEVICETYPE_TABLE = 8



_REQUESTTYPING = _descriptor.Descriptor(
  name='RequestTyping',
  full_name='dialog.RequestTyping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestTyping.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='typing_type', full_name='dialog.RequestTyping.typing_type', index=1,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=321,
)


_REQUESTSTOPTYPING = _descriptor.Descriptor(
  name='RequestStopTyping',
  full_name='dialog.RequestStopTyping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestStopTyping.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='typing_type', full_name='dialog.RequestStopTyping.typing_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=324,
  serialized_end=475,
)


_REQUESTSETONLINE = _descriptor.Descriptor(
  name='RequestSetOnline',
  full_name='dialog.RequestSetOnline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_online', full_name='dialog.RequestSetOnline.is_online', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='dialog.RequestSetOnline.timeout', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_type', full_name='dialog.RequestSetOnline.device_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_category', full_name='dialog.RequestSetOnline.device_category', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=718,
)


_UPDATEPAUSENOTIFICATIONS = _descriptor.Descriptor(
  name='UpdatePauseNotifications',
  full_name='dialog.UpdatePauseNotifications',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeout', full_name='dialog.UpdatePauseNotifications.timeout', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=720,
  serialized_end=778,
)


_UPDATERESTORENOTIFICATIONS = _descriptor.Descriptor(
  name='UpdateRestoreNotifications',
  full_name='dialog.UpdateRestoreNotifications',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=780,
  serialized_end=808,
)


_REQUESTPAUSENOTIFICATIONS = _descriptor.Descriptor(
  name='RequestPauseNotifications',
  full_name='dialog.RequestPauseNotifications',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeout', full_name='dialog.RequestPauseNotifications.timeout', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=810,
  serialized_end=898,
)


_REQUESTRESTORENOTIFICATIONS = _descriptor.Descriptor(
  name='RequestRestoreNotifications',
  full_name='dialog.RequestRestoreNotifications',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=900,
  serialized_end=959,
)


_UPDATETYPING = _descriptor.Descriptor(
  name='UpdateTyping',
  full_name='dialog.UpdateTyping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UpdateTyping.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateTyping.uid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='typing_type', full_name='dialog.UpdateTyping.typing_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=962,
  serialized_end=1103,
)


_UPDATETYPINGSTOP = _descriptor.Descriptor(
  name='UpdateTypingStop',
  full_name='dialog.UpdateTypingStop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UpdateTypingStop.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateTypingStop.uid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='typing_type', full_name='dialog.UpdateTypingStop.typing_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1106,
  serialized_end=1250,
)


_UPDATEUSERONLINE = _descriptor.Descriptor(
  name='UpdateUserOnline',
  full_name='dialog.UpdateUserOnline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateUserOnline.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_type', full_name='dialog.UpdateUserOnline.device_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_category', full_name='dialog.UpdateUserOnline.device_category', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1253,
  serialized_end=1395,
)


_UPDATEUSEROFFLINE = _descriptor.Descriptor(
  name='UpdateUserOffline',
  full_name='dialog.UpdateUserOffline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateUserOffline.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_type', full_name='dialog.UpdateUserOffline.device_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_category', full_name='dialog.UpdateUserOffline.device_category', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1398,
  serialized_end=1541,
)


_UPDATEUSERLASTSEEN = _descriptor.Descriptor(
  name='UpdateUserLastSeen',
  full_name='dialog.UpdateUserLastSeen',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateUserLastSeen.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.UpdateUserLastSeen.date', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_type', full_name='dialog.UpdateUserLastSeen.device_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_category', full_name='dialog.UpdateUserLastSeen.device_category', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1544,
  serialized_end=1717,
)


_UPDATEGROUPONLINE = _descriptor.Descriptor(
  name='UpdateGroupOnline',
  full_name='dialog.UpdateGroupOnline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.UpdateGroupOnline.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='dialog.UpdateGroupOnline.count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1719,
  serialized_end=1801,
)

_REQUESTTYPING.fields_by_name['peer'].message_type = peers__pb2._OUTPEER
_REQUESTTYPING.fields_by_name['typing_type'].enum_type = _TYPINGTYPE
_REQUESTSTOPTYPING.fields_by_name['peer'].message_type = peers__pb2._OUTPEER
_REQUESTSTOPTYPING.fields_by_name['typing_type'].enum_type = _TYPINGTYPE
_REQUESTSETONLINE.fields_by_name['device_type'].enum_type = _DEVICETYPE
_REQUESTSETONLINE.fields_by_name['device_category'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATETYPING.fields_by_name['peer'].message_type = peers__pb2._PEER
_UPDATETYPING.fields_by_name['typing_type'].enum_type = _TYPINGTYPE
_UPDATETYPINGSTOP.fields_by_name['peer'].message_type = peers__pb2._PEER
_UPDATETYPINGSTOP.fields_by_name['typing_type'].enum_type = _TYPINGTYPE
_UPDATEUSERONLINE.fields_by_name['device_type'].enum_type = _DEVICETYPE
_UPDATEUSERONLINE.fields_by_name['device_category'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEUSEROFFLINE.fields_by_name['device_type'].enum_type = _DEVICETYPE
_UPDATEUSEROFFLINE.fields_by_name['device_category'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_UPDATEUSERLASTSEEN.fields_by_name['device_type'].enum_type = _DEVICETYPE
_UPDATEUSERLASTSEEN.fields_by_name['device_category'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['RequestTyping'] = _REQUESTTYPING
DESCRIPTOR.message_types_by_name['RequestStopTyping'] = _REQUESTSTOPTYPING
DESCRIPTOR.message_types_by_name['RequestSetOnline'] = _REQUESTSETONLINE
DESCRIPTOR.message_types_by_name['UpdatePauseNotifications'] = _UPDATEPAUSENOTIFICATIONS
DESCRIPTOR.message_types_by_name['UpdateRestoreNotifications'] = _UPDATERESTORENOTIFICATIONS
DESCRIPTOR.message_types_by_name['RequestPauseNotifications'] = _REQUESTPAUSENOTIFICATIONS
DESCRIPTOR.message_types_by_name['RequestRestoreNotifications'] = _REQUESTRESTORENOTIFICATIONS
DESCRIPTOR.message_types_by_name['UpdateTyping'] = _UPDATETYPING
DESCRIPTOR.message_types_by_name['UpdateTypingStop'] = _UPDATETYPINGSTOP
DESCRIPTOR.message_types_by_name['UpdateUserOnline'] = _UPDATEUSERONLINE
DESCRIPTOR.message_types_by_name['UpdateUserOffline'] = _UPDATEUSEROFFLINE
DESCRIPTOR.message_types_by_name['UpdateUserLastSeen'] = _UPDATEUSERLASTSEEN
DESCRIPTOR.message_types_by_name['UpdateGroupOnline'] = _UPDATEGROUPONLINE
DESCRIPTOR.enum_types_by_name['TypingType'] = _TYPINGTYPE
DESCRIPTOR.enum_types_by_name['DeviceType'] = _DEVICETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RequestTyping = _reflection.GeneratedProtocolMessageType('RequestTyping', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTTYPING,
  __module__ = 'typing_and_online_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestTyping)
  ))
_sym_db.RegisterMessage(RequestTyping)

RequestStopTyping = _reflection.GeneratedProtocolMessageType('RequestStopTyping', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTSTOPTYPING,
  __module__ = 'typing_and_online_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestStopTyping)
  ))
_sym_db.RegisterMessage(RequestStopTyping)

RequestSetOnline = _reflection.GeneratedProtocolMessageType('RequestSetOnline', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTSETONLINE,
  __module__ = 'typing_and_online_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSetOnline)
  ))
_sym_db.RegisterMessage(RequestSetOnline)

UpdatePauseNotifications = _reflection.GeneratedProtocolMessageType('UpdatePauseNotifications', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEPAUSENOTIFICATIONS,
  __module__ = 'typing_and_online_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdatePauseNotifications)
  ))
_sym_db.RegisterMessage(UpdatePauseNotifications)

UpdateRestoreNotifications = _reflection.GeneratedProtocolMessageType('UpdateRestoreNotifications', (_message.Message,), dict(
  DESCRIPTOR = _UPDATERESTORENOTIFICATIONS,
  __module__ = 'typing_and_online_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateRestoreNotifications)
  ))
_sym_db.RegisterMessage(UpdateRestoreNotifications)

RequestPauseNotifications = _reflection.GeneratedProtocolMessageType('RequestPauseNotifications', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTPAUSENOTIFICATIONS,
  __module__ = 'typing_and_online_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestPauseNotifications)
  ))
_sym_db.RegisterMessage(RequestPauseNotifications)

RequestRestoreNotifications = _reflection.GeneratedProtocolMessageType('RequestRestoreNotifications', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTRESTORENOTIFICATIONS,
  __module__ = 'typing_and_online_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestRestoreNotifications)
  ))
_sym_db.RegisterMessage(RequestRestoreNotifications)

UpdateTyping = _reflection.GeneratedProtocolMessageType('UpdateTyping', (_message.Message,), dict(
  DESCRIPTOR = _UPDATETYPING,
  __module__ = 'typing_and_online_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateTyping)
  ))
_sym_db.RegisterMessage(UpdateTyping)

UpdateTypingStop = _reflection.GeneratedProtocolMessageType('UpdateTypingStop', (_message.Message,), dict(
  DESCRIPTOR = _UPDATETYPINGSTOP,
  __module__ = 'typing_and_online_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateTypingStop)
  ))
_sym_db.RegisterMessage(UpdateTypingStop)

UpdateUserOnline = _reflection.GeneratedProtocolMessageType('UpdateUserOnline', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEUSERONLINE,
  __module__ = 'typing_and_online_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateUserOnline)
  ))
_sym_db.RegisterMessage(UpdateUserOnline)

UpdateUserOffline = _reflection.GeneratedProtocolMessageType('UpdateUserOffline', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEUSEROFFLINE,
  __module__ = 'typing_and_online_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateUserOffline)
  ))
_sym_db.RegisterMessage(UpdateUserOffline)

UpdateUserLastSeen = _reflection.GeneratedProtocolMessageType('UpdateUserLastSeen', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEUSERLASTSEEN,
  __module__ = 'typing_and_online_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateUserLastSeen)
  ))
_sym_db.RegisterMessage(UpdateUserLastSeen)

UpdateGroupOnline = _reflection.GeneratedProtocolMessageType('UpdateGroupOnline', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEGROUPONLINE,
  __module__ = 'typing_and_online_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateGroupOnline)
  ))
_sym_db.RegisterMessage(UpdateGroupOnline)


DESCRIPTOR._options = None
_REQUESTTYPING.fields_by_name['peer']._options = None
_REQUESTTYPING.fields_by_name['typing_type']._options = None
_REQUESTTYPING._options = None
_REQUESTSTOPTYPING.fields_by_name['peer']._options = None
_REQUESTSTOPTYPING.fields_by_name['typing_type']._options = None
_REQUESTSTOPTYPING._options = None
_REQUESTSETONLINE.fields_by_name['is_online']._options = None
_REQUESTSETONLINE.fields_by_name['timeout']._options = None
_REQUESTSETONLINE.fields_by_name['device_type']._options = None
_REQUESTSETONLINE.fields_by_name['device_category']._options = None
_REQUESTSETONLINE._options = None
_UPDATEPAUSENOTIFICATIONS.fields_by_name['timeout']._options = None
_REQUESTPAUSENOTIFICATIONS.fields_by_name['timeout']._options = None
_REQUESTPAUSENOTIFICATIONS._options = None
_REQUESTRESTORENOTIFICATIONS._options = None
_UPDATETYPING.fields_by_name['peer']._options = None
_UPDATETYPING.fields_by_name['uid']._options = None
_UPDATETYPING.fields_by_name['typing_type']._options = None
_UPDATETYPINGSTOP.fields_by_name['peer']._options = None
_UPDATETYPINGSTOP.fields_by_name['uid']._options = None
_UPDATETYPINGSTOP.fields_by_name['typing_type']._options = None
_UPDATEUSERONLINE.fields_by_name['uid']._options = None
_UPDATEUSEROFFLINE.fields_by_name['uid']._options = None
_UPDATEUSERLASTSEEN.fields_by_name['uid']._options = None
_UPDATEUSERLASTSEEN.fields_by_name['date']._options = None
_UPDATEGROUPONLINE.fields_by_name['group_id']._options = None
_UPDATEGROUPONLINE.fields_by_name['count']._options = None

_TYPINGANDONLINE = _descriptor.ServiceDescriptor(
  name='TypingAndOnline',
  full_name='dialog.TypingAndOnline',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2078,
  serialized_end=2691,
  methods=[
  _descriptor.MethodDescriptor(
    name='Typing',
    full_name='dialog.TypingAndOnline.Typing',
    index=0,
    containing_service=None,
    input_type=_REQUESTTYPING,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=_b('\202\323\344\223\002$\"\037/v1/grpc/TypingAndOnline/Typing:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='StopTyping',
    full_name='dialog.TypingAndOnline.StopTyping',
    index=1,
    containing_service=None,
    input_type=_REQUESTSTOPTYPING,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=_b('\202\323\344\223\002(\"#/v1/grpc/TypingAndOnline/StopTyping:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='SetOnline',
    full_name='dialog.TypingAndOnline.SetOnline',
    index=2,
    containing_service=None,
    input_type=_REQUESTSETONLINE,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=_b('\202\323\344\223\002\'\"\"/v1/grpc/TypingAndOnline/SetOnline:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='PauseNotifications',
    full_name='dialog.TypingAndOnline.PauseNotifications',
    index=3,
    containing_service=None,
    input_type=_REQUESTPAUSENOTIFICATIONS,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=_b('\202\323\344\223\0020\"+/v1/grpc/TypingAndOnline/PauseNotifications:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='RestoreNotifications',
    full_name='dialog.TypingAndOnline.RestoreNotifications',
    index=4,
    containing_service=None,
    input_type=_REQUESTRESTORENOTIFICATIONS,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=_b('\202\323\344\223\0022\"-/v1/grpc/TypingAndOnline/RestoreNotifications:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_TYPINGANDONLINE)

DESCRIPTOR.services_by_name['TypingAndOnline'] = _TYPINGANDONLINE

# @@protoc_insertion_point(module_scope)



from .internal.peers import private_peer, group_peer, peer_hasher
from .dialog_api import peers_pb2, messaging_pb2, miscellaneous_pb2, contacts_pb2

DEFAULT_OPTIMIZATIONS = [
    miscellaneous_pb2.UPDATEOPTIMIZATION_STRIP_ENTITIES,
    miscellaneous_pb2.UPDATEOPTIMIZATION_STRIP_ENTITIES_V2,
    miscellaneous_pb2.UPDATEOPTIMIZATION_STRIP_COUNTERS,
    miscellaneous_pb2.UPDATEOPTIMIZATION_COMPACT_USERS
]


class EntityManager(object):
    """Entity manager class.

    """
    def __init__(self, internal):
        self.internal = internal
        self.peers_to_outpeers = {}
        self.bootstrap()

    def bootstrap(self):
        """Finds outpeers for all list of contacts.

        """
        contacts = self.internal.contacts.GetContacts(contacts_pb2.RequestGetContacts(
            optimizations=DEFAULT_OPTIMIZATIONS
        ))
        for user in contacts.user_peers:
            self.adopt_peer(user)

    def adopt_peer(self, peer):
        """Finds outpeer for given peer and store it in internal peers_to_outpeers dict.

        :param peer: Peer object
        """
        if isinstance(peer, peers_pb2.UserOutPeer):
            outpeer = peers_pb2.OutPeer(type=peers_pb2.PEERTYPE_PRIVATE, id=peer.uid, access_hash=peer.access_hash)
            self.peers_to_outpeers[peer_hasher(private_peer(peer.uid))] = outpeer
        elif isinstance(peer, peers_pb2.GroupOutPeer):
            outpeer = peers_pb2.OutPeer(type=peers_pb2.PEERTYPE_GROUP, id=peer.group_id, access_hash=peer.access_hash)
            self.peers_to_outpeers[peer_hasher(group_peer(peer.group_id))] = outpeer
        else:
            raise RuntimeError("Unknown peer type")

    def get_outpeer(self, peer):
        """Returns outpeer for given peer.

        :param peer: Peer object
        :return: OutPeer object
        """
        if isinstance(peer, peers_pb2.OutPeer):
            return peer

        peer_hash = peer_hasher(peer)
        result = self.peers_to_outpeers.get(peer_hash)
        if result is None:
            req = messaging_pb2.RequestLoadDialogs(
                min_date=0,
                limit=1,
                peers_to_load=[peer],
                optimizations=DEFAULT_OPTIMIZATIONS
            )
            result = self.internal.messaging.LoadDialogs(req)
            for user in result.user_peers:
                self.adopt_peer(user)
            for group in result.group_peers:
                self.adopt_peer(group)
            return self.peers_to_outpeers.get(peer_hash)
        return result



import os
import requests
from concurrent.futures import ThreadPoolExecutor
from tempfile import NamedTemporaryFile

from .utils.read_file_in_chunks import read_file_in_chunks
from .dialog_api import media_and_files_pb2


class Uploading(object):
    """Class for high-level file uploading interface.

    """

    def __init__(self, internal, cert, private_key, access_dir):
        self.internal = internal
        self.cert = cert
        self.private_key = private_key
        self.access_dir = access_dir

    def upload_file_chunk(self, part_number, chunk, upload_key, access_dir=None):
        """Upload file chunk.

        :param part_number: number of chunk (>=0)
        :param chunk: chunk content
        :param upload_key: upload key (need to be received from RequestGetFileUploadUrl request before uploading)
        :return: Response of HTTP PUT request if success or None otherwise
        """

        url = self.internal.media_and_files.GetFileUploadPartUrl(
            media_and_files_pb2.RequestGetFileUploadPartUrl(
                part_number=part_number,
                part_size=len(chunk),
                upload_key=upload_key
            )
        ).url

        if self.cert and self.private_key:
            with NamedTemporaryFile(dir=access_dir, delete=False) as cert_file:
                with NamedTemporaryFile(dir=access_dir, delete=False) as private_key_file:
                    cert_file.write(self.cert)
                    private_key_file.write(self.private_key)
                    cert_file.flush()
                    private_key_file.flush()
                    put_response = requests.put(
                        url,
                        data=chunk,
                        headers={'Content-Type': 'application/octet-stream'},
                        cert=(cert_file.name, private_key_file.name)
                    )
                    try:
                        cert_file.close()
                        private_key_file.close()
                        os.unlink(cert_file.name)
                        os.unlink(private_key_file.name)
                    except Exception as e:
                        print(e)
                        pass

        else:
            put_response = requests.put(
                url,
                data=chunk,
                headers={'Content-Type': 'application/octet-stream'},
            )

        if put_response.status_code != 200:
            print('Can\'t upload file chunk #{}'.format(part_number))
            return None

        return put_response

    def upload_file(self, file, max_chunk_size=1024*1024, parallelism=10):
        """Upload file for sending.

        :param file: path to file
        :param max_chunk_size: maximum size of one chunk (default 1024 * 1024)
        :param parallelism: number of uploading threads (default: 10)
        :return: FileLocation object if success or None otherwise
        """

        upload_key = self.internal.media_and_files.GetFileUploadUrl(
            media_and_files_pb2.RequestGetFileUploadUrl(
                expected_size=os.path.getsize(file)
            )
        ).upload_key

        with ThreadPoolExecutor(max_workers=parallelism) as executor:
            result = list(
                executor.map(
                    lambda x: self.upload_file_chunk(*x),
                    (
                        (part_number, chunk, upload_key, self.access_dir) for part_number, chunk in enumerate(
                            read_file_in_chunks(file, max_chunk_size)
                        )
                    )
                )
            )

            if not all(result):
                return None

        return self.internal.media_and_files.CommitFileUpload(
            media_and_files_pb2.RequestCommitFileUpload(
                upload_key=upload_key,
                file_name=os.path.basename(file)
            )
        ).uploaded_file_location



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stickers.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from . import media_and_files_pb2 as media__and__files__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='stickers.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=_b('\342?\026\n\024im.dlg.grpc.services'),
  serialized_pb=_b('\n\x0estickers.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x13miscellaneous.proto\x1a\x15media_and_files.proto\x1a\x15scalapb/scalapb.proto\"\x95\x02\n\x11StickerDescriptor\x12\x19\n\x02id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12:\n\x05\x65moji\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12\x37\n\timage_128\x18\x03 \x01(\x0b\x32\x15.dialog.ImageLocationB\r\x8a\xea\x30\t\n\x07visible\x12\x37\n\timage_512\x18\x04 \x01(\x0b\x32\x15.dialog.ImageLocationB\r\x8a\xea\x30\t\n\x07visible\x12\x37\n\timage_256\x18\x05 \x01(\x0b\x32\x15.dialog.ImageLocationB\r\x8a\xea\x30\t\n\x07visible\"\xe6\x01\n\x11StickerCollection\x12\x19\n\x02id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12:\n\x05title\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12:\n\x08stickers\x18\x03 \x03(\x0b\x32\x19.dialog.StickerDescriptorB\r\x8a\xea\x30\t\n\x07visible\x12>\n\x0bowned_by_me\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\r\x8a\xea\x30\t\n\x07visible\"\xb2\x01\n\x18ResponseStickersResponse\x12=\n\x0b\x63ollections\x18\x01 \x03(\x0b\x32\x19.dialog.StickerCollectionB\r\x8a\xea\x30\t\n\x07visible\x12\x1a\n\x03seq\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05state\x18\x03 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07visible:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"6\n\x16RequestLoadOwnStickers:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"i\n\x17ResponseLoadOwnStickers\x12/\n\x0cown_stickers\x18\x01 \x03(\x0b\x32\x19.dialog.StickerCollection:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"=\n\x1dRequestLoadAcesssibleStickers:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"w\n\x1eResponseLoadAcesssibleStickers\x12\x36\n\x13\x61\x63\x63\x65ssible_stickers\x18\x01 \x03(\x0b\x32\x19.dialog.StickerCollection:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"j\n\x1eRequestAddStickerPackReference\x12*\n\x13source_sticker_pack\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"m\n!RequestRemoveStickerPackReference\x12*\n\x13source_sticker_pack\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"h\n\x1fUpdateStickerCollectionsChanged\x12\x45\n\x13updated_collections\x18\x01 \x03(\x0b\x32\x19.dialog.StickerCollectionB\r\x8a\xea\x30\t\n\x07visible\":\n\x18UpdateStickerPackRemoved\x12\x1e\n\x07pack_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"P\n\x16UpdateStickerPackAdded\x12\x36\n\x04pack\x18\x01 \x01(\x0b\x32\x19.dialog.StickerCollectionB\r\x8a\xea\x30\t\n\x07visible\"Y\n\x1bRequestAddStickerCollection\x12\x1c\n\x05title\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"Y\n\x1eRequestRemoveStickerCollection\x12\x19\n\x02id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"W\n\x1cRequestLoadStickerCollection\x12\x19\n\x02id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"m\n\x1dResponseLoadStickerCollection\x12-\n\ncollection\x18\x01 \x01(\x0b\x32\x19.dialog.StickerCollection:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse2\x83\x08\n\x08Stickers\x12\x80\x01\n\x0fLoadOwnStickers\x12\x1e.dialog.RequestLoadOwnStickers\x1a\x1f.dialog.ResponseLoadOwnStickers\",\x82\xd3\xe4\x93\x02&\"!/v1/grpc/Stickers/LoadOwnStickers:\x01*\x12\x9c\x01\n\x16LoadAcesssibleStickers\x12%.dialog.RequestLoadAcesssibleStickers\x1a&.dialog.ResponseLoadAcesssibleStickers\"3\x82\xd3\xe4\x93\x02-\"(/v1/grpc/Stickers/LoadAcesssibleStickers:\x01*\x12\x8c\x01\n\x17\x41\x64\x64StickerPackReference\x12&.dialog.RequestAddStickerPackReference\x1a\x13.dialog.ResponseSeq\"4\x82\xd3\xe4\x93\x02.\")/v1/grpc/Stickers/AddStickerPackReference:\x01*\x12\x95\x01\n\x1aRemoveStickerPackReference\x12).dialog.RequestRemoveStickerPackReference\x1a\x13.dialog.ResponseSeq\"7\x82\xd3\xe4\x93\x02\x31\",/v1/grpc/Stickers/RemoveStickerPackReference:\x01*\x12\x83\x01\n\x14\x41\x64\x64StickerCollection\x12#.dialog.RequestAddStickerCollection\x1a\x13.dialog.ResponseSeq\"1\x82\xd3\xe4\x93\x02+\"&/v1/grpc/Stickers/AddStickerCollection:\x01*\x12\x8c\x01\n\x17RemoveStickerCollection\x12&.dialog.RequestRemoveStickerCollection\x1a\x13.dialog.ResponseSeq\"4\x82\xd3\xe4\x93\x02.\")/v1/grpc/Stickers/RemoveStickerCollection:\x01*\x12\x98\x01\n\x15LoadStickerCollection\x12$.dialog.RequestLoadStickerCollection\x1a%.dialog.ResponseLoadStickerCollection\"2\x82\xd3\xe4\x93\x02,\"\'/v1/grpc/Stickers/LoadStickerCollection:\x01*B\x19\xe2?\x16\n\x14im.dlg.grpc.servicesb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,miscellaneous__pb2.DESCRIPTOR,media__and__files__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_STICKERDESCRIPTOR = _descriptor.Descriptor(
  name='StickerDescriptor',
  full_name='dialog.StickerDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.StickerDescriptor.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='emoji', full_name='dialog.StickerDescriptor.emoji', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_128', full_name='dialog.StickerDescriptor.image_128', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_512', full_name='dialog.StickerDescriptor.image_512', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_256', full_name='dialog.StickerDescriptor.image_256', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=175,
  serialized_end=452,
)


_STICKERCOLLECTION = _descriptor.Descriptor(
  name='StickerCollection',
  full_name='dialog.StickerCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.StickerCollection.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.StickerCollection.title', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stickers', full_name='dialog.StickerCollection.stickers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owned_by_me', full_name='dialog.StickerCollection.owned_by_me', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=455,
  serialized_end=685,
)


_RESPONSESTICKERSRESPONSE = _descriptor.Descriptor(
  name='ResponseStickersResponse',
  full_name='dialog.ResponseStickersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collections', full_name='dialog.ResponseStickersResponse.collections', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.ResponseStickersResponse.seq', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.ResponseStickersResponse.state', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=688,
  serialized_end=866,
)


_REQUESTLOADOWNSTICKERS = _descriptor.Descriptor(
  name='RequestLoadOwnStickers',
  full_name='dialog.RequestLoadOwnStickers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=868,
  serialized_end=922,
)


_RESPONSELOADOWNSTICKERS = _descriptor.Descriptor(
  name='ResponseLoadOwnStickers',
  full_name='dialog.ResponseLoadOwnStickers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='own_stickers', full_name='dialog.ResponseLoadOwnStickers.own_stickers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=924,
  serialized_end=1029,
)


_REQUESTLOADACESSSIBLESTICKERS = _descriptor.Descriptor(
  name='RequestLoadAcesssibleStickers',
  full_name='dialog.RequestLoadAcesssibleStickers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1031,
  serialized_end=1092,
)


_RESPONSELOADACESSSIBLESTICKERS = _descriptor.Descriptor(
  name='ResponseLoadAcesssibleStickers',
  full_name='dialog.ResponseLoadAcesssibleStickers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accessible_stickers', full_name='dialog.ResponseLoadAcesssibleStickers.accessible_stickers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1094,
  serialized_end=1213,
)


_REQUESTADDSTICKERPACKREFERENCE = _descriptor.Descriptor(
  name='RequestAddStickerPackReference',
  full_name='dialog.RequestAddStickerPackReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_sticker_pack', full_name='dialog.RequestAddStickerPackReference.source_sticker_pack', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1215,
  serialized_end=1321,
)


_REQUESTREMOVESTICKERPACKREFERENCE = _descriptor.Descriptor(
  name='RequestRemoveStickerPackReference',
  full_name='dialog.RequestRemoveStickerPackReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_sticker_pack', full_name='dialog.RequestRemoveStickerPackReference.source_sticker_pack', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1323,
  serialized_end=1432,
)


_UPDATESTICKERCOLLECTIONSCHANGED = _descriptor.Descriptor(
  name='UpdateStickerCollectionsChanged',
  full_name='dialog.UpdateStickerCollectionsChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='updated_collections', full_name='dialog.UpdateStickerCollectionsChanged.updated_collections', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1434,
  serialized_end=1538,
)


_UPDATESTICKERPACKREMOVED = _descriptor.Descriptor(
  name='UpdateStickerPackRemoved',
  full_name='dialog.UpdateStickerPackRemoved',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pack_id', full_name='dialog.UpdateStickerPackRemoved.pack_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1540,
  serialized_end=1598,
)


_UPDATESTICKERPACKADDED = _descriptor.Descriptor(
  name='UpdateStickerPackAdded',
  full_name='dialog.UpdateStickerPackAdded',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pack', full_name='dialog.UpdateStickerPackAdded.pack', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1600,
  serialized_end=1680,
)


_REQUESTADDSTICKERCOLLECTION = _descriptor.Descriptor(
  name='RequestAddStickerCollection',
  full_name='dialog.RequestAddStickerCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.RequestAddStickerCollection.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1682,
  serialized_end=1771,
)


_REQUESTREMOVESTICKERCOLLECTION = _descriptor.Descriptor(
  name='RequestRemoveStickerCollection',
  full_name='dialog.RequestRemoveStickerCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestRemoveStickerCollection.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1773,
  serialized_end=1862,
)


_REQUESTLOADSTICKERCOLLECTION = _descriptor.Descriptor(
  name='RequestLoadStickerCollection',
  full_name='dialog.RequestLoadStickerCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestLoadStickerCollection.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1864,
  serialized_end=1951,
)


_RESPONSELOADSTICKERCOLLECTION = _descriptor.Descriptor(
  name='ResponseLoadStickerCollection',
  full_name='dialog.ResponseLoadStickerCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection', full_name='dialog.ResponseLoadStickerCollection.collection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1953,
  serialized_end=2062,
)

_STICKERDESCRIPTOR.fields_by_name['emoji'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STICKERDESCRIPTOR.fields_by_name['image_128'].message_type = media__and__files__pb2._IMAGELOCATION
_STICKERDESCRIPTOR.fields_by_name['image_512'].message_type = media__and__files__pb2._IMAGELOCATION
_STICKERDESCRIPTOR.fields_by_name['image_256'].message_type = media__and__files__pb2._IMAGELOCATION
_STICKERCOLLECTION.fields_by_name['title'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STICKERCOLLECTION.fields_by_name['stickers'].message_type = _STICKERDESCRIPTOR
_STICKERCOLLECTION.fields_by_name['owned_by_me'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_RESPONSESTICKERSRESPONSE.fields_by_name['collections'].message_type = _STICKERCOLLECTION
_RESPONSELOADOWNSTICKERS.fields_by_name['own_stickers'].message_type = _STICKERCOLLECTION
_RESPONSELOADACESSSIBLESTICKERS.fields_by_name['accessible_stickers'].message_type = _STICKERCOLLECTION
_UPDATESTICKERCOLLECTIONSCHANGED.fields_by_name['updated_collections'].message_type = _STICKERCOLLECTION
_UPDATESTICKERPACKADDED.fields_by_name['pack'].message_type = _STICKERCOLLECTION
_RESPONSELOADSTICKERCOLLECTION.fields_by_name['collection'].message_type = _STICKERCOLLECTION
DESCRIPTOR.message_types_by_name['StickerDescriptor'] = _STICKERDESCRIPTOR
DESCRIPTOR.message_types_by_name['StickerCollection'] = _STICKERCOLLECTION
DESCRIPTOR.message_types_by_name['ResponseStickersResponse'] = _RESPONSESTICKERSRESPONSE
DESCRIPTOR.message_types_by_name['RequestLoadOwnStickers'] = _REQUESTLOADOWNSTICKERS
DESCRIPTOR.message_types_by_name['ResponseLoadOwnStickers'] = _RESPONSELOADOWNSTICKERS
DESCRIPTOR.message_types_by_name['RequestLoadAcesssibleStickers'] = _REQUESTLOADACESSSIBLESTICKERS
DESCRIPTOR.message_types_by_name['ResponseLoadAcesssibleStickers'] = _RESPONSELOADACESSSIBLESTICKERS
DESCRIPTOR.message_types_by_name['RequestAddStickerPackReference'] = _REQUESTADDSTICKERPACKREFERENCE
DESCRIPTOR.message_types_by_name['RequestRemoveStickerPackReference'] = _REQUESTREMOVESTICKERPACKREFERENCE
DESCRIPTOR.message_types_by_name['UpdateStickerCollectionsChanged'] = _UPDATESTICKERCOLLECTIONSCHANGED
DESCRIPTOR.message_types_by_name['UpdateStickerPackRemoved'] = _UPDATESTICKERPACKREMOVED
DESCRIPTOR.message_types_by_name['UpdateStickerPackAdded'] = _UPDATESTICKERPACKADDED
DESCRIPTOR.message_types_by_name['RequestAddStickerCollection'] = _REQUESTADDSTICKERCOLLECTION
DESCRIPTOR.message_types_by_name['RequestRemoveStickerCollection'] = _REQUESTREMOVESTICKERCOLLECTION
DESCRIPTOR.message_types_by_name['RequestLoadStickerCollection'] = _REQUESTLOADSTICKERCOLLECTION
DESCRIPTOR.message_types_by_name['ResponseLoadStickerCollection'] = _RESPONSELOADSTICKERCOLLECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StickerDescriptor = _reflection.GeneratedProtocolMessageType('StickerDescriptor', (_message.Message,), dict(
  DESCRIPTOR = _STICKERDESCRIPTOR,
  __module__ = 'stickers_pb2'
  # @@protoc_insertion_point(class_scope:dialog.StickerDescriptor)
  ))
_sym_db.RegisterMessage(StickerDescriptor)

StickerCollection = _reflection.GeneratedProtocolMessageType('StickerCollection', (_message.Message,), dict(
  DESCRIPTOR = _STICKERCOLLECTION,
  __module__ = 'stickers_pb2'
  # @@protoc_insertion_point(class_scope:dialog.StickerCollection)
  ))
_sym_db.RegisterMessage(StickerCollection)

ResponseStickersResponse = _reflection.GeneratedProtocolMessageType('ResponseStickersResponse', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSESTICKERSRESPONSE,
  __module__ = 'stickers_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseStickersResponse)
  ))
_sym_db.RegisterMessage(ResponseStickersResponse)

RequestLoadOwnStickers = _reflection.GeneratedProtocolMessageType('RequestLoadOwnStickers', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTLOADOWNSTICKERS,
  __module__ = 'stickers_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLoadOwnStickers)
  ))
_sym_db.RegisterMessage(RequestLoadOwnStickers)

ResponseLoadOwnStickers = _reflection.GeneratedProtocolMessageType('ResponseLoadOwnStickers', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSELOADOWNSTICKERS,
  __module__ = 'stickers_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseLoadOwnStickers)
  ))
_sym_db.RegisterMessage(ResponseLoadOwnStickers)

RequestLoadAcesssibleStickers = _reflection.GeneratedProtocolMessageType('RequestLoadAcesssibleStickers', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTLOADACESSSIBLESTICKERS,
  __module__ = 'stickers_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLoadAcesssibleStickers)
  ))
_sym_db.RegisterMessage(RequestLoadAcesssibleStickers)

ResponseLoadAcesssibleStickers = _reflection.GeneratedProtocolMessageType('ResponseLoadAcesssibleStickers', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSELOADACESSSIBLESTICKERS,
  __module__ = 'stickers_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseLoadAcesssibleStickers)
  ))
_sym_db.RegisterMessage(ResponseLoadAcesssibleStickers)

RequestAddStickerPackReference = _reflection.GeneratedProtocolMessageType('RequestAddStickerPackReference', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTADDSTICKERPACKREFERENCE,
  __module__ = 'stickers_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestAddStickerPackReference)
  ))
_sym_db.RegisterMessage(RequestAddStickerPackReference)

RequestRemoveStickerPackReference = _reflection.GeneratedProtocolMessageType('RequestRemoveStickerPackReference', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTREMOVESTICKERPACKREFERENCE,
  __module__ = 'stickers_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestRemoveStickerPackReference)
  ))
_sym_db.RegisterMessage(RequestRemoveStickerPackReference)

UpdateStickerCollectionsChanged = _reflection.GeneratedProtocolMessageType('UpdateStickerCollectionsChanged', (_message.Message,), dict(
  DESCRIPTOR = _UPDATESTICKERCOLLECTIONSCHANGED,
  __module__ = 'stickers_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateStickerCollectionsChanged)
  ))
_sym_db.RegisterMessage(UpdateStickerCollectionsChanged)

UpdateStickerPackRemoved = _reflection.GeneratedProtocolMessageType('UpdateStickerPackRemoved', (_message.Message,), dict(
  DESCRIPTOR = _UPDATESTICKERPACKREMOVED,
  __module__ = 'stickers_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateStickerPackRemoved)
  ))
_sym_db.RegisterMessage(UpdateStickerPackRemoved)

UpdateStickerPackAdded = _reflection.GeneratedProtocolMessageType('UpdateStickerPackAdded', (_message.Message,), dict(
  DESCRIPTOR = _UPDATESTICKERPACKADDED,
  __module__ = 'stickers_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateStickerPackAdded)
  ))
_sym_db.RegisterMessage(UpdateStickerPackAdded)

RequestAddStickerCollection = _reflection.GeneratedProtocolMessageType('RequestAddStickerCollection', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTADDSTICKERCOLLECTION,
  __module__ = 'stickers_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestAddStickerCollection)
  ))
_sym_db.RegisterMessage(RequestAddStickerCollection)

RequestRemoveStickerCollection = _reflection.GeneratedProtocolMessageType('RequestRemoveStickerCollection', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTREMOVESTICKERCOLLECTION,
  __module__ = 'stickers_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestRemoveStickerCollection)
  ))
_sym_db.RegisterMessage(RequestRemoveStickerCollection)

RequestLoadStickerCollection = _reflection.GeneratedProtocolMessageType('RequestLoadStickerCollection', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTLOADSTICKERCOLLECTION,
  __module__ = 'stickers_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLoadStickerCollection)
  ))
_sym_db.RegisterMessage(RequestLoadStickerCollection)

ResponseLoadStickerCollection = _reflection.GeneratedProtocolMessageType('ResponseLoadStickerCollection', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSELOADSTICKERCOLLECTION,
  __module__ = 'stickers_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseLoadStickerCollection)
  ))
_sym_db.RegisterMessage(ResponseLoadStickerCollection)


DESCRIPTOR._options = None
_STICKERDESCRIPTOR.fields_by_name['id']._options = None
_STICKERDESCRIPTOR.fields_by_name['emoji']._options = None
_STICKERDESCRIPTOR.fields_by_name['image_128']._options = None
_STICKERDESCRIPTOR.fields_by_name['image_512']._options = None
_STICKERDESCRIPTOR.fields_by_name['image_256']._options = None
_STICKERCOLLECTION.fields_by_name['id']._options = None
_STICKERCOLLECTION.fields_by_name['title']._options = None
_STICKERCOLLECTION.fields_by_name['stickers']._options = None
_STICKERCOLLECTION.fields_by_name['owned_by_me']._options = None
_RESPONSESTICKERSRESPONSE.fields_by_name['collections']._options = None
_RESPONSESTICKERSRESPONSE.fields_by_name['seq']._options = None
_RESPONSESTICKERSRESPONSE.fields_by_name['state']._options = None
_RESPONSESTICKERSRESPONSE._options = None
_REQUESTLOADOWNSTICKERS._options = None
_RESPONSELOADOWNSTICKERS._options = None
_REQUESTLOADACESSSIBLESTICKERS._options = None
_RESPONSELOADACESSSIBLESTICKERS._options = None
_REQUESTADDSTICKERPACKREFERENCE.fields_by_name['source_sticker_pack']._options = None
_REQUESTADDSTICKERPACKREFERENCE._options = None
_REQUESTREMOVESTICKERPACKREFERENCE.fields_by_name['source_sticker_pack']._options = None
_REQUESTREMOVESTICKERPACKREFERENCE._options = None
_UPDATESTICKERCOLLECTIONSCHANGED.fields_by_name['updated_collections']._options = None
_UPDATESTICKERPACKREMOVED.fields_by_name['pack_id']._options = None
_UPDATESTICKERPACKADDED.fields_by_name['pack']._options = None
_REQUESTADDSTICKERCOLLECTION.fields_by_name['title']._options = None
_REQUESTADDSTICKERCOLLECTION._options = None
_REQUESTREMOVESTICKERCOLLECTION.fields_by_name['id']._options = None
_REQUESTREMOVESTICKERCOLLECTION._options = None
_REQUESTLOADSTICKERCOLLECTION.fields_by_name['id']._options = None
_REQUESTLOADSTICKERCOLLECTION._options = None
_RESPONSELOADSTICKERCOLLECTION._options = None

_STICKERS = _descriptor.ServiceDescriptor(
  name='Stickers',
  full_name='dialog.Stickers',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2065,
  serialized_end=3092,
  methods=[
  _descriptor.MethodDescriptor(
    name='LoadOwnStickers',
    full_name='dialog.Stickers.LoadOwnStickers',
    index=0,
    containing_service=None,
    input_type=_REQUESTLOADOWNSTICKERS,
    output_type=_RESPONSELOADOWNSTICKERS,
    serialized_options=_b('\202\323\344\223\002&\"!/v1/grpc/Stickers/LoadOwnStickers:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='LoadAcesssibleStickers',
    full_name='dialog.Stickers.LoadAcesssibleStickers',
    index=1,
    containing_service=None,
    input_type=_REQUESTLOADACESSSIBLESTICKERS,
    output_type=_RESPONSELOADACESSSIBLESTICKERS,
    serialized_options=_b('\202\323\344\223\002-\"(/v1/grpc/Stickers/LoadAcesssibleStickers:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='AddStickerPackReference',
    full_name='dialog.Stickers.AddStickerPackReference',
    index=2,
    containing_service=None,
    input_type=_REQUESTADDSTICKERPACKREFERENCE,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=_b('\202\323\344\223\002.\")/v1/grpc/Stickers/AddStickerPackReference:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='RemoveStickerPackReference',
    full_name='dialog.Stickers.RemoveStickerPackReference',
    index=3,
    containing_service=None,
    input_type=_REQUESTREMOVESTICKERPACKREFERENCE,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=_b('\202\323\344\223\0021\",/v1/grpc/Stickers/RemoveStickerPackReference:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='AddStickerCollection',
    full_name='dialog.Stickers.AddStickerCollection',
    index=4,
    containing_service=None,
    input_type=_REQUESTADDSTICKERCOLLECTION,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=_b('\202\323\344\223\002+\"&/v1/grpc/Stickers/AddStickerCollection:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='RemoveStickerCollection',
    full_name='dialog.Stickers.RemoveStickerCollection',
    index=5,
    containing_service=None,
    input_type=_REQUESTREMOVESTICKERCOLLECTION,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=_b('\202\323\344\223\002.\")/v1/grpc/Stickers/RemoveStickerCollection:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='LoadStickerCollection',
    full_name='dialog.Stickers.LoadStickerCollection',
    index=6,
    containing_service=None,
    input_type=_REQUESTLOADSTICKERCOLLECTION,
    output_type=_RESPONSELOADSTICKERCOLLECTION,
    serialized_options=_b('\202\323\344\223\002,\"\'/v1/grpc/Stickers/LoadStickerCollection:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_STICKERS)

DESCRIPTOR.services_by_name['Stickers'] = _STICKERS

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import crypto_pb2 as crypto__pb2


class CryptoStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.KeyExchange = channel.unary_unary(
        '/dialog.Crypto/KeyExchange',
        request_serializer=crypto__pb2.RequestKeyExchange.SerializeToString,
        response_deserializer=crypto__pb2.ResponseKeyExchange.FromString,
        )


class CryptoServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def KeyExchange(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CryptoServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'KeyExchange': grpc.unary_unary_rpc_method_handler(
          servicer.KeyExchange,
          request_deserializer=crypto__pb2.RequestKeyExchange.FromString,
          response_serializer=crypto__pb2.ResponseKeyExchange.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dialog.Crypto', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: raw_api.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='raw_api.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=_b('\342?\026\n\024im.dlg.grpc.services'),
  serialized_pb=_b('\n\rraw_api.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x15scalapb/scalapb.proto\"\xa8\x01\n\x11RequestRawRequest\x12<\n\x07service\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12\x37\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.BytesValueB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"^\n\x12ResponseRawRequest\x12)\n\x04\x62ody\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.BytesValue:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse2t\n\x06RawAPI\x12j\n\nRawRequest\x12\x19.dialog.RequestRawRequest\x1a\x1a.dialog.ResponseRawRequest\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v1/grpc/RawAPI/RawRequest:\x01*B\x19\xe2?\x16\n\x14im.dlg.grpc.servicesb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_REQUESTRAWREQUEST = _descriptor.Descriptor(
  name='RequestRawRequest',
  full_name='dialog.RequestRawRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='service', full_name='dialog.RequestRawRequest.service', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='dialog.RequestRawRequest.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=298,
)


_RESPONSERAWREQUEST = _descriptor.Descriptor(
  name='ResponseRawRequest',
  full_name='dialog.ResponseRawRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='body', full_name='dialog.ResponseRawRequest.body', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=300,
  serialized_end=394,
)

_REQUESTRAWREQUEST.fields_by_name['service'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REQUESTRAWREQUEST.fields_by_name['body'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_RESPONSERAWREQUEST.fields_by_name['body'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
DESCRIPTOR.message_types_by_name['RequestRawRequest'] = _REQUESTRAWREQUEST
DESCRIPTOR.message_types_by_name['ResponseRawRequest'] = _RESPONSERAWREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RequestRawRequest = _reflection.GeneratedProtocolMessageType('RequestRawRequest', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTRAWREQUEST,
  __module__ = 'raw_api_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestRawRequest)
  ))
_sym_db.RegisterMessage(RequestRawRequest)

ResponseRawRequest = _reflection.GeneratedProtocolMessageType('ResponseRawRequest', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSERAWREQUEST,
  __module__ = 'raw_api_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseRawRequest)
  ))
_sym_db.RegisterMessage(ResponseRawRequest)


DESCRIPTOR._options = None
_REQUESTRAWREQUEST.fields_by_name['service']._options = None
_REQUESTRAWREQUEST.fields_by_name['body']._options = None
_REQUESTRAWREQUEST._options = None
_RESPONSERAWREQUEST._options = None

_RAWAPI = _descriptor.ServiceDescriptor(
  name='RawAPI',
  full_name='dialog.RawAPI',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=396,
  serialized_end=512,
  methods=[
  _descriptor.MethodDescriptor(
    name='RawRequest',
    full_name='dialog.RawAPI.RawRequest',
    index=0,
    containing_service=None,
    input_type=_REQUESTRAWREQUEST,
    output_type=_RESPONSERAWREQUEST,
    serialized_options=_b('\202\323\344\223\002\037\"\032/v1/grpc/RawAPI/RawRequest:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_RAWAPI)

DESCRIPTOR.services_by_name['RawAPI'] = _RAWAPI

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import search_pb2 as search__pb2


class SearchStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.PeerSearch = channel.unary_unary(
        '/dialog.Search/PeerSearch',
        request_serializer=search__pb2.RequestPeerSearch.SerializeToString,
        response_deserializer=search__pb2.ResponsePeerSearch.FromString,
        )
    self.ResolvePeer = channel.unary_unary(
        '/dialog.Search/ResolvePeer',
        request_serializer=search__pb2.RequestResolvePeer.SerializeToString,
        response_deserializer=search__pb2.ResponseResolvePeer.FromString,
        )
    self.MessageSearch = channel.unary_unary(
        '/dialog.Search/MessageSearch',
        request_serializer=search__pb2.RequestMessageSearch.SerializeToString,
        response_deserializer=search__pb2.ResponseMessageSearchResponse.FromString,
        )
    self.MessageSearchMore = channel.unary_unary(
        '/dialog.Search/MessageSearchMore',
        request_serializer=search__pb2.RequestMessageSearchMore.SerializeToString,
        response_deserializer=search__pb2.ResponseMessageSearchResponse.FromString,
        )
    self.SimpleSearch = channel.unary_unary(
        '/dialog.Search/SimpleSearch',
        request_serializer=search__pb2.RequestSimpleSearch.SerializeToString,
        response_deserializer=search__pb2.ResponseMessageSearchResponse.FromString,
        )
    self.SimpleSearchMore = channel.unary_unary(
        '/dialog.Search/SimpleSearchMore',
        request_serializer=search__pb2.RequestSimpleSearchMore.SerializeToString,
        response_deserializer=search__pb2.ResponseMessageSearchResponse.FromString,
        )
    self.AutocompleteSuggestions = channel.unary_unary(
        '/dialog.Search/AutocompleteSuggestions',
        request_serializer=search__pb2.RequestFieldAutocomplete.SerializeToString,
        response_deserializer=search__pb2.ResponseFieldAutocomplete.FromString,
        )
    self.LoadUserSearchByPredicatesResults = channel.unary_unary(
        '/dialog.Search/LoadUserSearchByPredicatesResults',
        request_serializer=search__pb2.RequestLoadUserSearchByPredicatesResults.SerializeToString,
        response_deserializer=search__pb2.ResponseLoadUserSearchByPredicatesResults.FromString,
        )
    self.LoadUserSearchByPredicatesCount = channel.unary_unary(
        '/dialog.Search/LoadUserSearchByPredicatesCount',
        request_serializer=search__pb2.RequestLoadUserSearchByPredicatesCount.SerializeToString,
        response_deserializer=search__pb2.ResponseLoadUserSearchByPredicatesCount.FromString,
        )


class SearchServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def PeerSearch(self, request, context):
    """/ Search among groups/users/contacts
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ResolvePeer(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MessageSearch(self, request, context):
    """/ Search by messages
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MessageSearchMore(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SimpleSearch(self, request, context):
    """/ Custom search by conditions
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SimpleSearchMore(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AutocompleteSuggestions(self, request, context):
    """/ Search for autocomplete suggestions among custom user profile
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def LoadUserSearchByPredicatesResults(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def LoadUserSearchByPredicatesCount(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_SearchServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'PeerSearch': grpc.unary_unary_rpc_method_handler(
          servicer.PeerSearch,
          request_deserializer=search__pb2.RequestPeerSearch.FromString,
          response_serializer=search__pb2.ResponsePeerSearch.SerializeToString,
      ),
      'ResolvePeer': grpc.unary_unary_rpc_method_handler(
          servicer.ResolvePeer,
          request_deserializer=search__pb2.RequestResolvePeer.FromString,
          response_serializer=search__pb2.ResponseResolvePeer.SerializeToString,
      ),
      'MessageSearch': grpc.unary_unary_rpc_method_handler(
          servicer.MessageSearch,
          request_deserializer=search__pb2.RequestMessageSearch.FromString,
          response_serializer=search__pb2.ResponseMessageSearchResponse.SerializeToString,
      ),
      'MessageSearchMore': grpc.unary_unary_rpc_method_handler(
          servicer.MessageSearchMore,
          request_deserializer=search__pb2.RequestMessageSearchMore.FromString,
          response_serializer=search__pb2.ResponseMessageSearchResponse.SerializeToString,
      ),
      'SimpleSearch': grpc.unary_unary_rpc_method_handler(
          servicer.SimpleSearch,
          request_deserializer=search__pb2.RequestSimpleSearch.FromString,
          response_serializer=search__pb2.ResponseMessageSearchResponse.SerializeToString,
      ),
      'SimpleSearchMore': grpc.unary_unary_rpc_method_handler(
          servicer.SimpleSearchMore,
          request_deserializer=search__pb2.RequestSimpleSearchMore.FromString,
          response_serializer=search__pb2.ResponseMessageSearchResponse.SerializeToString,
      ),
      'AutocompleteSuggestions': grpc.unary_unary_rpc_method_handler(
          servicer.AutocompleteSuggestions,
          request_deserializer=search__pb2.RequestFieldAutocomplete.FromString,
          response_serializer=search__pb2.ResponseFieldAutocomplete.SerializeToString,
      ),
      'LoadUserSearchByPredicatesResults': grpc.unary_unary_rpc_method_handler(
          servicer.LoadUserSearchByPredicatesResults,
          request_deserializer=search__pb2.RequestLoadUserSearchByPredicatesResults.FromString,
          response_serializer=search__pb2.ResponseLoadUserSearchByPredicatesResults.SerializeToString,
      ),
      'LoadUserSearchByPredicatesCount': grpc.unary_unary_rpc_method_handler(
          servicer.LoadUserSearchByPredicatesCount,
          request_deserializer=search__pb2.RequestLoadUserSearchByPredicatesCount.FromString,
          response_serializer=search__pb2.ResponseLoadUserSearchByPredicatesCount.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dialog.Search', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import registration_pb2 as registration__pb2


class RegistrationStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.ExchangeAuthIdForToken = channel.unary_unary(
        '/dialog.Registration/ExchangeAuthIdForToken',
        request_serializer=registration__pb2.RequestExchangeAuthIdForToken.SerializeToString,
        response_deserializer=registration__pb2.ResponseDeviceRequest.FromString,
        )
    self.RegisterDevice = channel.unary_unary(
        '/dialog.Registration/RegisterDevice',
        request_serializer=registration__pb2.RequestRegisterDevice.SerializeToString,
        response_deserializer=registration__pb2.ResponseDeviceRequest.FromString,
        )
    self.RegisterDeprecatedDevice = channel.unary_unary(
        '/dialog.Registration/RegisterDeprecatedDevice',
        request_serializer=registration__pb2.RegisterDeprecatedDeviceRequest.SerializeToString,
        response_deserializer=registration__pb2.ResponseDeviceRequest.FromString,
        )


class RegistrationServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def ExchangeAuthIdForToken(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RegisterDevice(self, request, context):
    """/ register device to get auth token
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RegisterDeprecatedDevice(self, request, context):
    """deprecated
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_RegistrationServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'ExchangeAuthIdForToken': grpc.unary_unary_rpc_method_handler(
          servicer.ExchangeAuthIdForToken,
          request_deserializer=registration__pb2.RequestExchangeAuthIdForToken.FromString,
          response_serializer=registration__pb2.ResponseDeviceRequest.SerializeToString,
      ),
      'RegisterDevice': grpc.unary_unary_rpc_method_handler(
          servicer.RegisterDevice,
          request_deserializer=registration__pb2.RequestRegisterDevice.FromString,
          response_serializer=registration__pb2.ResponseDeviceRequest.SerializeToString,
      ),
      'RegisterDeprecatedDevice': grpc.unary_unary_rpc_method_handler(
          servicer.RegisterDeprecatedDevice,
          request_deserializer=registration__pb2.RegisterDeprecatedDeviceRequest.FromString,
          response_serializer=registration__pb2.ResponseDeviceRequest.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dialog.Registration', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import media_and_files_pb2 as media__and__files__pb2


class MediaAndFilesStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetFileUrl = channel.unary_unary(
        '/dialog.MediaAndFiles/GetFileUrl',
        request_serializer=media__and__files__pb2.RequestGetFileUrl.SerializeToString,
        response_deserializer=media__and__files__pb2.ResponseGetFileUrl.FromString,
        )
    self.GetFileUrls = channel.unary_unary(
        '/dialog.MediaAndFiles/GetFileUrls',
        request_serializer=media__and__files__pb2.RequestGetFileUrls.SerializeToString,
        response_deserializer=media__and__files__pb2.ResponseGetFileUrls.FromString,
        )
    self.GetFileUrlBuilder = channel.unary_unary(
        '/dialog.MediaAndFiles/GetFileUrlBuilder',
        request_serializer=media__and__files__pb2.RequestGetFileUrlBuilder.SerializeToString,
        response_deserializer=media__and__files__pb2.ResponseGetFileUrlBuilder.FromString,
        )
    self.GetFileUploadUrl = channel.unary_unary(
        '/dialog.MediaAndFiles/GetFileUploadUrl',
        request_serializer=media__and__files__pb2.RequestGetFileUploadUrl.SerializeToString,
        response_deserializer=media__and__files__pb2.ResponseGetFileUploadUrl.FromString,
        )
    self.CommitFileUpload = channel.unary_unary(
        '/dialog.MediaAndFiles/CommitFileUpload',
        request_serializer=media__and__files__pb2.RequestCommitFileUpload.SerializeToString,
        response_deserializer=media__and__files__pb2.ResponseCommitFileUpload.FromString,
        )
    self.GetFileUploadPartUrl = channel.unary_unary(
        '/dialog.MediaAndFiles/GetFileUploadPartUrl',
        request_serializer=media__and__files__pb2.RequestGetFileUploadPartUrl.SerializeToString,
        response_deserializer=media__and__files__pb2.ResponseGetFileUploadPartUrl.FromString,
        )


class MediaAndFilesServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def GetFileUrl(self, request, context):
    """/ Get link to file for downloading
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetFileUrls(self, request, context):
    """/ Get link to files for downloading
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetFileUrlBuilder(self, request, context):
    """/ Create builder for file url
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetFileUploadUrl(self, request, context):
    """/ Get url for uploading
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CommitFileUpload(self, request, context):
    """/ Finish uploading a file
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetFileUploadPartUrl(self, request, context):
    """/ Get url for uploading chunk of file
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_MediaAndFilesServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetFileUrl': grpc.unary_unary_rpc_method_handler(
          servicer.GetFileUrl,
          request_deserializer=media__and__files__pb2.RequestGetFileUrl.FromString,
          response_serializer=media__and__files__pb2.ResponseGetFileUrl.SerializeToString,
      ),
      'GetFileUrls': grpc.unary_unary_rpc_method_handler(
          servicer.GetFileUrls,
          request_deserializer=media__and__files__pb2.RequestGetFileUrls.FromString,
          response_serializer=media__and__files__pb2.ResponseGetFileUrls.SerializeToString,
      ),
      'GetFileUrlBuilder': grpc.unary_unary_rpc_method_handler(
          servicer.GetFileUrlBuilder,
          request_deserializer=media__and__files__pb2.RequestGetFileUrlBuilder.FromString,
          response_serializer=media__and__files__pb2.ResponseGetFileUrlBuilder.SerializeToString,
      ),
      'GetFileUploadUrl': grpc.unary_unary_rpc_method_handler(
          servicer.GetFileUploadUrl,
          request_deserializer=media__and__files__pb2.RequestGetFileUploadUrl.FromString,
          response_serializer=media__and__files__pb2.ResponseGetFileUploadUrl.SerializeToString,
      ),
      'CommitFileUpload': grpc.unary_unary_rpc_method_handler(
          servicer.CommitFileUpload,
          request_deserializer=media__and__files__pb2.RequestCommitFileUpload.FromString,
          response_serializer=media__and__files__pb2.ResponseCommitFileUpload.SerializeToString,
      ),
      'GetFileUploadPartUrl': grpc.unary_unary_rpc_method_handler(
          servicer.GetFileUploadPartUrl,
          request_deserializer=media__and__files__pb2.RequestGetFileUploadPartUrl.FromString,
          response_serializer=media__and__files__pb2.ResponseGetFileUploadPartUrl.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dialog.MediaAndFiles', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
